@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ void activate_button_clicked(struct w *widgets)
     {
 	/* Check if secure FTP is enabled in the combo. If so, require certificates before start. */
 	active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[14]));
-	if( active_index != 1 ) /* '1' is Off */
+	if( active_index != 1 ) /* '1' is Off. (Proftpd wants the file even though the module is not on ?) */
 	{
 	    cert_dir  = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[15]));
 	    cert_path =  g_strdup_printf("%s/cert.pem", cert_dir);
