@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,7 +66,6 @@ extern int global_dir_error;
 /* Temporary, for option deprecations in proftpd */
 extern char global_version[1024];
 
-
 extern gchar *GP_PASSWD_BUF;
 extern gchar *GP_GROUP_BUF;
 
@@ -102,7 +101,7 @@ long get_virtual_hnumber()
 	if( strlen(line) < 3 )
 	  continue;
 	  
-	// Get value from 3:rd or 4:th section
+	/* Get value from 3:rd or 4:th section */
 	tmp = strtok(line, ":");
 
 	count = 0; tmpnumber = 0;	
@@ -129,27 +128,26 @@ long get_virtual_hnumber()
 }
 
 
-
 void add_user(struct w *widgets)
 {
     /* Adds a new user to the selected server */
     FILE *fp;
-    long hnumber = 0, conf_size = 0;
+    long hnumber = 0, file_size = 0;
     long profile_size = 0;
-    char *old_buffer, *new_buffer;
-    char *user_check, *address_buffer, *port_buffer;
+    char *line, *new_buffer;
+    char *address_buffer=NULL, *port_buffer=NULL;
     const char *encrypted_pass;
     int length=0, limit_access=0, user_added=0;
     int found_server=0, standard_server=0;
     gchar *utf8=NULL;
     gchar *info, *cmd, *restricted_dir=NULL;
-    G_CONST_RETURN gchar *br=NULL, *brc=NULL, *fr=NULL, *frc=NULL;
 
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *password;
     G_CONST_RETURN gchar *group;
     G_CONST_RETURN gchar *comment;
     G_CONST_RETURN gchar *shell;
+    G_CONST_RETURN gchar *br=NULL, *brc=NULL, *fr=NULL, *frc=NULL;
 
     username  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
     password  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
@@ -249,124 +247,12 @@ void add_user(struct w *widgets)
     	return;
     }
 
-    /* Check if the user exists in the selected server */
-    if((fp=fopen(PROFTPD_CONF,"r"))==NULL)
-    {
-	info = g_strdup_printf(_("Failed adding user: %s\nCant open proftpd.conf.\n"), username);
-	show_info(info);
-	g_free(info);
-
-    	return;
-    }
-    fseek(fp, 0, SEEK_END);
-    conf_size = ftell(fp);
-    rewind(fp);
-
-    old_buffer = allocate(conf_size);
-    user_check = allocate(4096);
-
-    snprintf(user_check, 4000, "User %s\n", username);
-
-    address_buffer = allocate(8192+15);
-    port_buffer = allocate(8192+3);               
-
-    if( strstr((char *)global_server_type, "Virtualhost") )
-      sprintf(address_buffer, "<VirtualHost %s>\n", global_server_address);
-    else
-      standard_server = 1;
-     
-    sprintf(port_buffer, "Port %s\n", global_server_port);
-
-
-    /* Scroll to the correct vhost */
-    if( ! standard_server && conf_size > 1 )
-    while(fgets(old_buffer, conf_size, fp)!=NULL)
-    {
-	/* The correct server address is found */
-        if( ! found_server && strcmp(old_buffer, address_buffer) == 0 ) 
-	{
-	    /* Lets see if its the same port as the selected one */
-	    while(fgets(old_buffer, conf_size, fp)!=NULL)
-	    {
-		if( strstr(old_buffer, "Port") 
-		&&  strcmp(old_buffer, port_buffer) == 0 )
-		{
-		    found_server = 1;
-		    break;
-		}
-		/* End of vhost, break and check the next vhost */
-		if( strstr(old_buffer, "</VirtualHost>") )
-		  break;
-	    }    
-	}
-	/* This vhost has the correct address and port */
-	if( found_server )
-	  break;
-    }
-
-    /* The selected vhost was not found */
-    if( ! standard_server && ! found_server )
-    {
-	info = g_strdup_printf(_("Failed adding user: %s\nThe selected virtual host was not found.\n"), username);
-	show_info(info);
-	g_free(info);
-
-	free(old_buffer);
-	free(user_check);
-	free(address_buffer);
-	free(port_buffer);
-	fclose(fp);
-	return;
-    }
-
-
-    /* We have begun at the top for the standard server 
-     * or scrolled to the selected vhost. */
-    
-    /* Check if the user exists in this selected vhost or standard server */
-    if( conf_size > 1 )
-    while(fgets(old_buffer, conf_size, fp)!=NULL)
-    {
-	if( strcmp(old_buffer, user_check)  == 0
-	&&  strstr(old_buffer, "AllowUser") == 0
-	&&  strstr(old_buffer, "FakeUser")  == 0)
-	{
-	    info = g_strdup_printf(_("Failed adding user: %s\nThe user already exists in this server.\n"), username);
- 	    show_info(info);
-	    g_free(info);
-
-	    free(old_buffer);
-	    free(user_check);
-	    free(address_buffer);
-	    free(port_buffer);
-	    fclose(fp);
-	    return;
-	}
-
-	/* End the search if we are looking for a standard user 
-	   and the end of the standard server is found */
-	if( standard_server && strstr(old_buffer, "<VirtualHost") )
-	  break;
-
-	/* End the search if we are looking for a vhost user 
-	   and the end of the vhost is found */
-	if( ! standard_server && strstr(old_buffer, "</VirtualHost") )
-	  break;
-    }
-    free(user_check);
-    free(old_buffer);
-    fclose(fp);
-
-
-
-
-
     /* Virtual users */
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->server_set_check_virtual)) )
     {
 	if( ! strstr(GP_PASSWD_BUF, "/users/") )
 	{
-	    printf("add_user.c: Safeguard activated\n");
+	    printf("add_user.c: Safeguard activated. Virtual user path must contain: .../users/...\n");
 	    return;
 	}
 
@@ -426,7 +312,6 @@ void add_user(struct w *widgets)
 	fclose(fp);
 	g_free(info);
 	
-
 	/* Append to proftpd.group / group:x:1001 */
 	info = g_strdup_printf("%s:x:%ld\n", group, hnumber);	
 	
@@ -446,8 +331,6 @@ void add_user(struct w *widgets)
     {
           /* Begin system users */
 
-
-
 	/* The selected shell is false, add the group and the user with a false shell and home /dev/null */
 	if( strstr(shell, "nologin") || strstr(shell, "false") || strstr(shell, "dev/null") )
 	{
@@ -500,7 +383,6 @@ void add_user(struct w *widgets)
 	}
 	else 	
         {
-
             /* The selected shell is not false add a real user account */
 #ifndef USE_DARWIN
 
@@ -562,19 +444,15 @@ void add_user(struct w *widgets)
  	    show_info(info);
 	    g_free(info);
 
-	    free(address_buffer);
-	    free(port_buffer);
 	    return;
 	}
-
     }   /* End of adding system or virtual users */
 
 
-
     /* Setup the users profile and create its directories */
 
     /* Set the homedir globally from the first row in the treeview using row_pos=0 */
-    num_rows = 0;/* Set global num_rows */
+    num_rows = 0; /* Set global num_rows */
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) num_rows_func, widgets);
 
     if( num_rows < 1 )
@@ -608,7 +486,6 @@ void add_user(struct w *widgets)
 	return;
     }
     
-
     /* If ratios is used it needs a restricted toplevel directory and
        a block all .ftpaccess file in this toplevel directory */
     if( use_ratio )
@@ -668,7 +545,7 @@ void add_user(struct w *widgets)
     strcat(user_profile, group);
     strcat(user_profile, "\n");
     strcat(user_profile, "AnonRequirePassword on\n");
-    strcat(user_profile, "MaxClients 5 \"The server is full, hosting %m users\"\n");
+    strcat(user_profile, "MaxClients 10 \"The server is full, hosting %m users\"\n");
     strcat(user_profile, "DisplayLogin welcome.msg\n");
 
     /* Fix for a changed directive, sorry Fedora backported... */
@@ -709,7 +586,6 @@ void add_user(struct w *widgets)
     if( homedir!=NULL )
       g_free(homedir);
 
-
     /* Add the new user settings and AllowUser to the correct server */
     found_server = 0;
 
@@ -720,53 +596,61 @@ void add_user(struct w *widgets)
     /* Add AllowUser UserName to the selected server */
     if((fp=fopen(PROFTPD_CONF,"r"))==NULL)
     {
-	free(address_buffer);
-	free(port_buffer);
 	free(user_profile);
     	return;
     }
     fseek(fp, 0, SEEK_END);
-    conf_size = ftell(fp);
+    file_size = ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(conf_size);
-    new_buffer = allocate(conf_size+8192);
+    line = allocate(file_size+1);
+    new_buffer = allocate(file_size+8192);
+    address_buffer = allocate(1024);
+    port_buffer    = allocate(1024);
 
-    if( conf_size > 1 )
-    while(fgets(old_buffer, conf_size, fp)!=NULL)
+    if( strstr((char *)global_server_type, "Virtualhost") )
+      sprintf(address_buffer, "<VirtualHost %s>\n", global_server_address);
+    else
     {
-	strcat(new_buffer, old_buffer);
+        standard_server = 1;
+        found_server    = 1;
+    }                 
+    sprintf(port_buffer, "Port %s\n", global_server_port);
 
-        if( ! standard_server && ! found_server 
-	&&  strcmp(old_buffer, address_buffer) == 0 )
+
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+	strcat(new_buffer, line);
+
+	if( ! standard_server && ! found_server
+	&&  strcmp(line, address_buffer) == 0 )
 	{
 	    /* Lets see if this is the selected server */
-	    while(fgets(old_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, file_size, fp)!=NULL)
 	    {
-		strcat(new_buffer, old_buffer);
+		strcat(new_buffer, line);
 
 		/* This will expect the servers port on the second line ! 
 		 * else itll miss some vaules .. */
-		if( strstr(old_buffer, "Port") 
-		&& strcmp(old_buffer, port_buffer) == 0 )
+		if( strstr(line, "Port")
+		&&  strcmp(line, port_buffer) == 0 )
 		{
 		    found_server = 1;
 		    break;
 		}
 		
-		if( strstr(old_buffer, "</Virtualhost>") )
+		if( strstr(line, "</Virtualhost>") )
 		  break;
 	    }    
 	}
-
 	
 	/* Continue until we find the selected server */
 	if( ! found_server )
 	  continue;
 
-
 	/* Add AllowUser Username .. to this server only */
-	if( strstr(old_buffer, "<Limit LOGIN") 
+	if( strstr(line, "<Limit LOGIN") 
 	&& found_server && ! limit_access )
 	{
 	    strcat(new_buffer, "  AllowUser ");
@@ -775,10 +659,10 @@ void add_user(struct w *widgets)
 	    limit_access = 1; /* just incase so we just change the first occurance */
 	    
 	    /* Add the user after </Limit> */
-	    while(fgets(old_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, file_size, fp)!=NULL)
 	    {
-	       strcat(new_buffer, old_buffer);
-	       if( strstr(old_buffer, "</Limit") && limit_access == 1 )
+	       strcat(new_buffer, line);
+	       if( strstr(line, "</Limit") && limit_access == 1 )
 	       {
 		    /* Only add it once */
 		    limit_access = 2;
@@ -786,9 +670,9 @@ void add_user(struct w *widgets)
 	       }
 	    }
 	}
-	
+
 	/* Add the new user settings if we have another user (once) */
-	if( strstr(old_buffer, "</Anonymous") && limit_access == 1 )
+	if( strstr(line, "</Anonymous") && limit_access == 1 )
 	{
 	   /* Only add it once */
 	   limit_access = 2;
@@ -796,7 +680,7 @@ void add_user(struct w *widgets)
 	}
     }
     fclose(fp);
-    free(old_buffer);      
+    free(line);      
     free(address_buffer);
     free(port_buffer);
     free(user_profile);
@@ -840,7 +724,6 @@ void add_user(struct w *widgets)
 	     fclose(fp);
     	  }
     }
-
     free(new_buffer);      
 
     fix_newlines_in_conf();
