@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,8 +82,6 @@ void apply_server_settings(struct w *widgets)
     G_CONST_RETURN gchar *systemlog;
     G_CONST_RETURN gchar *default_username_length;
     G_CONST_RETURN gchar *default_password_length;
-//    G_CONST_RETURN gchar *default_home_path;
-//    G_CONST_RETURN gchar *default_upload_path;
     G_CONST_RETURN gchar *default_html_path;
 
     /* TLS Entries */
@@ -91,14 +89,11 @@ void apply_server_settings(struct w *widgets)
     G_CONST_RETURN gchar *tls_logfile = NULL;
     G_CONST_RETURN gchar *tls_certfile = NULL;
 
-
     /* Get settings from the entries */
     server_name = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[0]));
     server_ident = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[1]));
     masquerade_address = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[2]));
     admin_email = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[3]));
-//    default_home_path = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[4]));
-//    default_upload_path = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[5]));
     default_html_path = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[6]));
     systemlog = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[8]));
     server_user = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[9]));
@@ -699,12 +694,9 @@ void apply_server_settings(struct w *widgets)
 	    printf("The virtualhost was not found, no changes where made.\n");
 
 	    fclose(fp);
-
 	    free(change_srv_ident);
             g_free(old_server_ident);
 	    free(config);
-
-	    printf("Broken...\n");
 	    return;
 	}
 
