@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,12 +28,12 @@
 #include "functions.h"
 #include "reread_conf.h"
 #include "show_info.h"
+#include "add_user.h"
 #include "apply_user.h"
 #include "allocate.h"
 #include "populate_users.h"
 #include "populate_user_settings.h"
 #include "populate_conf_tab.h"
-
 #include "dir_treeview_funcs.h"
 
 extern char global_server_address[1024];
@@ -41,7 +41,6 @@ extern char global_server_port[1024];
 extern char global_server_type[1024];
 
 extern int activated;
-
 extern int use_ratio;
 extern int use_quota;
 
@@ -49,16 +48,134 @@ extern int use_quota;
 extern char global_version[1024];
 
 /* The current directory beeing added and limited */
-//gchar *dir; // ???
 extern gchar *homedir;
 
-/* The 18 checkbox values */
-gchar *dir_val[19]; // ???
-
-char *user_profile; // ???
-
+/* The directory checkbox values */
+gchar *dir_val[19];
 extern long num_rows;
 extern int row_pos;
+char *user_profile;
+
+
+int user_exists_in_selected_server(struct w *widgets, gchar *username)
+{
+    FILE *fp;
+    long file_size = 0;
+    char *line, *user_check;
+    char *address_buffer, *port_buffer;
+    int found_server=0, standard_server=0;
+    gchar *info;
+
+    /* Check if the user exists in the selected server */
+    if((fp=fopen(PROFTPD_CONF,"r"))==NULL)
+    {
+//	info = g_strdup_printf(_("Failed adding user: %s\nCant open proftpd.conf.\n"), username);
+//	show_info(info);
+//	g_free(info);
+
+    	return 0;
+    }
+    fseek(fp, 0, SEEK_END);
+    file_size = ftell(fp);
+    rewind(fp);
+
+    line           = allocate(file_size);
+    address_buffer = allocate(8192+15);
+    port_buffer    = allocate(8192+3);               
+    user_check     = allocate(4096);
+
+    snprintf(user_check, 4000, "User %s\n", username);
+
+    if( strstr((char *)global_server_type, "Virtualhost") )
+      sprintf(address_buffer, "<VirtualHost %s>\n", global_server_address);
+    else
+      standard_server = 1;
+     
+    sprintf(port_buffer, "Port %s\n", global_server_port);
+
+    /* Scroll to the correct vhost */
+    if( ! standard_server && file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+	/* The correct server address is found */
+        if( ! found_server && strcmp(line, address_buffer) == 0 ) 
+	{
+	    /* Lets see if its the same port as the selected one */
+	    while(fgets(line, file_size, fp)!=NULL)
+	    {
+		if( strstr(line, "Port") 
+		&&  strcmp(line, port_buffer) == 0 )
+		{
+		    found_server = 1;
+		    break;
+		}
+		/* End of vhost, break and check the next vhost */
+		if( strstr(line, "</VirtualHost>") )
+		  break;
+	    }    
+	}
+	/* This vhost has the correct address and port */
+	if( found_server )
+	  break;
+    }
+
+    /* The selected vhost was not found */
+    if( ! standard_server && ! found_server )
+    {
+//	info = g_strdup_printf(_("Failed adding user: %s\nThe selected virtual host was not found.\n"), username);
+//	show_info(info);
+//	g_free(info);
+
+	fclose(fp);
+	free(user_check);
+	free(line);
+	free(address_buffer);
+	free(port_buffer);
+
+	return 0;
+    }
+
+    /* We have begun at the top for the standard server or scrolled to the selected vhost. */
+    
+    /* Check if the user exists in this selected vhost or standard server */
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+	if( strcmp(line, user_check) == 0
+	&& ! strstr(line, "AllowUser")
+	&& ! strstr(line, "FakeUser")    )
+	{
+//	    info = g_strdup_printf(_("Failed adding user: %s\nThe user already exists in this server.\n"), username);
+// 	    show_info(info);
+//	    g_free(info);
+
+	    fclose(fp);
+	    free(user_check);
+	    free(line);
+	    free(address_buffer);
+	    free(port_buffer);
+
+	    return 1;
+	}
+
+	/* End the search if we are looking for a standard user 
+	   and the end of the standard server is found */
+	if( standard_server && strstr(line, "<VirtualHost") )
+	  break;
+
+	/* End the search if we are looking for a vhost user 
+	   and the end of the vhost is found */
+	if( ! standard_server && strstr(line, "</VirtualHost") )
+	  break;
+    }
+    fclose(fp);
+    free(user_check);
+    free(line);
+    free(address_buffer);
+    free(port_buffer);
+
+    return 0;
+}
 
 
 /* Fixme mod: group, comment and shell */
@@ -67,10 +184,10 @@ void apply_user(struct w *widgets)
     /* Change the selected users configuration. */
     /* First delete the user from the conf then add it */
     FILE *fp;
-    long conf_size;
+    long file_size;
     int password_length = 0;
     gchar *info;
-    char *old_buffer, *new_buffer, *config, *address_buffer, *port_buffer;
+    char *line, *new_buffer, *config, *address_buffer, *port_buffer;
     long profile_size = 0;
     int user_changed = 0;
     int found = 0;
@@ -102,7 +219,6 @@ void apply_user(struct w *widgets)
 	frc = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[4]));
     }
 
-
     if( password!=NULL )
       password_length = strlen(password);
 
@@ -115,7 +231,6 @@ void apply_user(struct w *widgets)
         return;
     }
 
-
     /* Set global num_rows */
     num_rows = 0;
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) num_rows_func, widgets);
@@ -129,6 +244,18 @@ void apply_user(struct w *widgets)
 	return;    
     }
 
+
+    if( ! user_exists_in_selected_server(widgets, (gchar *)username) )
+    {
+	/* Add a new user */
+	printf("This user does not exist, adding it...\n");
+
+	add_user(widgets);
+
+        return;
+    }
+
+
     /* (Global char) Statics + entries + number of rows (dirlen + APPE STOR STOU etc) */
     profile_size = 16384 + 1400 + (num_rows * 16384);
     /* Allocate the user profile */
@@ -144,9 +271,6 @@ void apply_user(struct w *widgets)
     /* Home directory */
     snprintf(user_profile, 16384, "\n<Anonymous %s>\n", homedir);
 
-
-
-
     /* Username */    
     strcat(user_profile, "User ");
     strcat(user_profile, username);
@@ -251,34 +375,34 @@ void apply_user(struct w *widgets)
         return;
     }
     fseek(fp, 0, SEEK_END);
-    conf_size = ftell(fp);
+    file_size = ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(conf_size+3);
-    config = allocate(conf_size+profile_size+3);
+    line = allocate(file_size+3);
+    config = allocate(file_size+profile_size+3);
 
 
     /* If the selected server is a vhost we collect everything up to
        the first vhost with the same name as the selected one */
     if( strstr((char *)global_server_type, "Virtualhost") )
     {
-	if( conf_size > 1 )
-	while(fgets(old_buffer, conf_size, fp)!=NULL)
+	if( file_size > 1 )
+	while(fgets(line, file_size, fp)!=NULL)
 	{
-	    strcat(config, old_buffer);
+	    strcat(config, line);
 	    
 	    /* If its the correct address */
-	    if( strcmp(old_buffer, address_buffer) == 0 )
+	    if( strcmp(line, address_buffer) == 0 )
 	    {
-	       while(fgets(old_buffer, conf_size, fp)!=NULL)
+	       while(fgets(line, file_size, fp)!=NULL)
 	       {
-		  strcat(config, old_buffer);
+		  strcat(config, line);
 		 
 		  /* This server was not the right one */
-		  if( strstr(old_buffer, "</VirtualHost>") )
+		  if( strstr(line, "</VirtualHost>") )
 		    break;
 		 
-		  if( strcmp(old_buffer, port_buffer) == 0 )
+		  if( strcmp(line, port_buffer) == 0 )
 		  {
 		     found = 1;
 	             break;
@@ -296,20 +420,20 @@ void apply_user(struct w *widgets)
     new_buffer = allocate(8192);
 
     /* Change the selected users settings */
-    if( conf_size > 1 )
-    while(fgets(old_buffer, conf_size, fp)!=NULL)
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
     {
-	if( strstr(old_buffer, "<Anonymous ") )
+	if( strstr(line, "<Anonymous ") )
 	{
 	    /* Save this directory incase its not the correct user */
-	    strcat(new_buffer, old_buffer);
+	    strcat(new_buffer, line);
 
-	    while(fgets(old_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, file_size, fp)!=NULL)
 	    {
 		/* This is the correct user in the correct server */
-        	if( strstr(old_buffer, UserUsername) 
-		&& ! strstr(old_buffer, "AllowUser") 
-		&& ! strstr(old_buffer, "DirFakeUser") && ! user_changed )
+        	if( strstr(line, UserUsername) 
+		&& ! strstr(line, "AllowUser") 
+		&& ! strstr(line, "DirFakeUser") && ! user_changed )
         	{
 		    /* The new profile is added */
 		    strcat(config, user_profile);
@@ -317,19 +441,19 @@ void apply_user(struct w *widgets)
 		    user_changed = 1;
 
 		    /* The old profile is deleted */
-		    while(fgets(old_buffer, conf_size, fp)!=NULL)
+		    while(fgets(line, file_size, fp)!=NULL)
 		    {
-			if( strstr(old_buffer, "</Anonymous") )
+			if( strstr(line, "</Anonymous") )
 			  break;
 
 			/* Some more safety breaks */
-			if( strstr(old_buffer, "<Anonymous") )
+			if( strstr(line, "<Anonymous") )
 			  break;
 
-			if( strstr(old_buffer, "</VirutalHost") )
+			if( strstr(line, "</VirutalHost") )
 			  break;
 
-			if( strstr(old_buffer, "<VirutalHost") )
+			if( strstr(line, "<VirutalHost") )
 			  break;
 		    }
 		}
@@ -340,15 +464,15 @@ void apply_user(struct w *widgets)
 		        strcat(config, new_buffer);
 		        new_buffer[0]='\0';
 		     }
-		     strcat(config, old_buffer);
+		     strcat(config, line);
 		     break;
 		  }
 	    }
 	}
 	else
-	  strcat(config, old_buffer);
+	  strcat(config, line);
     }
-    free(old_buffer);
+    free(line);
     free(new_buffer);
     g_free(UserUsername);
     fclose(fp);
@@ -409,26 +533,26 @@ void apply_user(struct w *widgets)
 	    else
 	      {
 	         fseek(fp, 0, SEEK_END);
-	         conf_size = ftell(fp);
+	         file_size = ftell(fp);
 	         rewind(fp);
 		 
-	         config = allocate(conf_size+4096);        
-	         old_buffer = allocate(conf_size+4096);        
+	         config = allocate(file_size+4096);        
+	         line = allocate(file_size+4096);        
 		 temp_user = allocate(8192);
 		 
-		 if( conf_size > 1 )
-		 while(fgets(old_buffer, conf_size, fp)!=NULL)
+		 if( file_size > 1 )
+		 while(fgets(line, file_size, fp)!=NULL)
 		 {
-		    sscanf(old_buffer, "%s", temp_user);
+		    sscanf(line, "%s", temp_user);
 		    if( strcmp(temp_user, username) == 0 )
 		    {
 			/* Remove it */
 		    }
 		    else
-	    	      strcat(config, old_buffer);
+	    	      strcat(config, line);
 		 }			
 		 fclose(fp);
-		 free(old_buffer);
+		 free(line);
 		 free(temp_user);
 
 		 if((fp=fopen(GP_FTPUSERS, "w+"))==NULL) 
@@ -487,7 +611,6 @@ void apply_user(struct w *widgets)
 	}
     }
 
-
     fix_newlines_in_conf();
 
     /* Update the userlist */
