@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,4 +33,11 @@ int using_quota(void);
 void init_start(struct w *widgets);
 void init_stop(struct w *widgets);
 
+char * get_dynamic_module_statements();
+char * get_included_dynamic_module_statements(char *path);
+
+int using_module(char module_name[1024]);
+int using_included_module(char module_name[1024]);
+int module_in_include_path(char *path, char module_name[1024]);
+
 #endif
