@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ int commented(char *line)
 	    }
 
 	    /* Skip whitespace */
-	    if( line[i]==' ' )
+	    if( line[i]==' ' || line[i]=='\t' )
 	      continue;
 	    
 	    /* If the first char thats not whitespace is '#' or ';'
