@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include "generate_cert.h"
 #include "create_server_settings.h"
 #include "populate_conf_tab.h"
+#include "functions.h"
 
 extern int use_tls;
 extern int use_ratio;
@@ -98,6 +99,70 @@ void restrict_pam_conf(int add_del)
     /* Write the new conf */
     if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
     {
+	free(new_conf);
+        return; 
+    }
+    fputs(new_conf, fp);
+    fclose(fp);
+    free(new_conf);
+}
+
+
+/* Add or remove AuthUserFile and AuthGroupFile directives.
+   1 to add, 0 to remove the directives. */
+void virtual_user_directives(int add_del)
+{
+    FILE *fp;
+    long file_size = 0;
+    char *line, *new_conf;
+    gchar *directives;
+    gchar *auth_user_file, *auth_group_file;
+
+    if((fp=fopen(PROFTPD_CONF, "r"))==NULL)
+    {
+	/* We dont want to add anything unless the conf exists. */
+        return;
+    }
+    fseek(fp, 0, SEEK_END);
+    file_size = ftell(fp);
+    rewind(fp);
+
+    line     = allocate(file_size+1);
+    new_conf = allocate(file_size+1024);
+
+    auth_user_file  = g_strdup_printf("%s/users/proftpd.passwd", GP_APPCONFDIR);
+    auth_group_file = g_strdup_printf("%s/users/proftpd.group", GP_APPCONFDIR);
+
+    directives = g_strconcat(
+    "AuthUserFile ", auth_user_file, "\n",
+    "AuthGroupFile ", auth_group_file, "\n\n",
+    NULL);
+
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+	/* Remove the directives */
+	if( (cmplowercase(line, "authuserfile ") || cmplowercase(line, "authgroupfile ")) && add_del == 0 )
+        {
+	    continue;
+	}
+	else /* Add the directives before the tls module */
+	if( strstr(line, "<IfModule mod_tls.c>") && add_del == 1 )
+	{
+	    strcat(new_conf, directives);
+	    strcat(new_conf, line);
+	}
+	else
+	  strcat(new_conf, line);
+    }
+    fclose(fp);
+    free(line);
+    g_free(directives);
+
+    /* Write the new conf */
+    if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
+    {
+	free(new_conf);
         return; 
     }
     fputs(new_conf, fp);
@@ -126,7 +191,12 @@ void virtual_users_toggled(GtkToggleButton *togglebutton, struct w *widgets)
 	show_info(info);
 	g_free(info);
 	
+	/* Restrict PAM authentications. */
 	restrict_pam_conf(1);
+
+	/* Add virtual AuthUserFile and AuthGroupFile statements .*/
+	virtual_user_directives(1);
+
 	populate_conf_tab(widgets);
     }
     else
@@ -142,7 +212,12 @@ void virtual_users_toggled(GtkToggleButton *togglebutton, struct w *widgets)
 	show_info(info);
 	g_free(info);
 
+	/* Remove PAM Authentication restriction. */
 	restrict_pam_conf(0);
+	
+	/* Remove AuthUserFile and AuthGroupFile statements. */
+	virtual_user_directives(0);
+	
 	populate_conf_tab(widgets);
     }
 }
