@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include "create_user_tab.h"
 #include "user_treeview_row_clicked.h"
 #include "populate_shell_combo.h"
-#include "add_user.h"
 #include "apply_user.h"
 #include "file_chooser.h"
 
@@ -208,6 +207,11 @@ void create_user_tab(struct w *widgets)
 		      G_CALLBACK(user_treeview_row_clicked), widgets);
 
 
+    /* The delete, new user and apply buttonbox */
+    widgets->user_button_box = gtk_hbutton_box_new();
+    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox2), widgets->user_button_box, FALSE, FALSE, 0);
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(widgets->user_button_box), GTK_BUTTONBOX_SPREAD);
+
 
     /* Create the user settings scrolled window with a frame and a table */
     user_settings_treeview_hbox = gtk_hbox_new(TRUE, 0);
@@ -228,7 +232,7 @@ void create_user_tab(struct w *widgets)
     /* Add a frame */
     frame = gtk_frame_new(_("User settings and directories:"));
 
-    /* A table with NUM settings and 2 columns FIXME, Count */
+    /* A table with NUM settings and 2 columns */
     widgets->usr_set_table = gtk_table_new(NUM_USERTAB_ENTRIES+NUM_USERTAB_SPINBUTTONS+NUM_USERTAB_CHECKBUTTONS+NUM_USERTAB_COMBOS, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), widgets->usr_set_table);
@@ -244,7 +248,7 @@ void create_user_tab(struct w *widgets)
     gtk_widget_set_size_request(directory_scrolled_window, -1, 100);
 
 
-    /* 19 columns */
+    /* Directory store with some columns... */
     widgets->directory_store = gtk_list_store_new(19, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
     G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
     G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, 
@@ -317,6 +321,7 @@ void create_user_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(label340), GTK_JUSTIFY_LEFT);
 
     /* A second apply button does the same as the one in the user frame */
+/*
     GtkWidget *apply_directory_button = gtk_button_new();
     gtk_box_pack_start(GTK_BOX(add_dir_hbox), apply_directory_button, FALSE, FALSE, 0);
     gtk_tooltips_set_tip(tooltips, apply_directory_button, _("Apply changes after adding directories and setting permissions."), NULL);
@@ -332,10 +337,10 @@ void create_user_tab(struct w *widgets)
     GtkWidget *label238 = gtk_label_new_with_mnemonic(_("Apply changes"));
     gtk_box_pack_start(GTK_BOX(hbox68), label238, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label238), GTK_JUSTIFY_LEFT);
-
+*/
     /* The second apply buttons signal hookup */
-    g_signal_connect_swapped(apply_directory_button, "clicked",
-                    	     G_CALLBACK(apply_user), widgets);
+//    g_signal_connect_swapped(apply_directory_button, "clicked",
+//                    	     G_CALLBACK(apply_user), widgets);
 
     /* Make the directory cell editable */
     dir_cell_renderer = gtk_cell_renderer_text_new();
