@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -116,7 +116,7 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strcmp(username, tempname) == 0 )
 			{
@@ -154,7 +154,7 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(username, tempname) 
 			&& strlen(username) == strlen(tempname) )
@@ -204,7 +204,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strcmp(groupname, tempname) == 0 )
 			{
@@ -239,7 +239,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(groupname, tempname) && strlen(groupname)==strlen(tempname) )
 			{
@@ -524,8 +524,6 @@ password_virtual_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *pass
 		if( strcmp(username, tmp) == 0 )
 		{
 		    match = 1;
-
-		    printf("Usernames Match: %s\n", tmp);
 		}
 		
 		break;
@@ -539,8 +537,6 @@ password_virtual_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *pass
 	
 	    if( match && count == 3 )
 	    {
-		printf("Count and match!\n");
-	    
 		snprintf(part, file_size, "%s", &line[i+1]);
 		break;
 	    }
@@ -1098,8 +1094,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 106;
     	  
-	    if( u_arr[where]!="0" && u_arr[where]!="1" && u_arr[where]!="2" && u_arr[where]!="3" && u_arr[where]!="4"
-	    &&  u_arr[where]!="5" && u_arr[where]!="6" && u_arr[where]!="7" && u_arr[where]!="8" && u_arr[where]!="9" )
+	    if( ! chars_are_digits(u_arr[where]) )
 	    {
 		strcpy(rnd_string, u_arr[where]);
                 break;
@@ -1110,8 +1105,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 53;
 
-            if( l_arr[where]!="0" && l_arr[where]!="1" && l_arr[where]!="2" && l_arr[where]!="3" && l_arr[where]!="4"
-	    &&  l_arr[where]!="5" && l_arr[where]!="6" && l_arr[where]!="7" && l_arr[where]!="8" && l_arr[where]!="9" )
+	    if( ! chars_are_digits(l_arr[where]) )
 	    {
 		strcpy(rnd_string, l_arr[where]);
     	        break;
