@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,11 +84,12 @@ char global_version[1024]="";
 int main(int argc, char *argv[])
 {
     FILE *fp;
-    int i=0, auto_security = 0;
+    int i = 0, auto_security = 0;
     gchar *conf_path, *info=NULL, *utf8=NULL;
     gchar *cmd, *openssl_conf, *settings_conf, *settings;
 
     /* Missing pam file in FC-3,4,5,6,7 proftpd rpm so its added if missing. */
+    /* Thanks to Mathias for fixing it. GW! */
     gchar *broken_fedora;
 
 #ifdef ENABLE_NLS
@@ -129,25 +130,25 @@ int main(int argc, char *argv[])
 	return 0;
     }
 
-
     /* Create the main window */
     create_main_window(widgets);
 
     /* Set ProFTPD Version */
     set_version(widgets);
 
-    /* If proftpd has the mod_tls module we 
+    /* If proftpd has the mod_tls.c module we 
        create, show and use the TLS widgets */
-    use_tls = using_tls();
+    use_tls = using_module("mod_tls.c");
 
-    /* If proftpd has the mod_ratio module we 
+    /* If proftpd has the mod_ratio.c module we 
        create, show and use the RATIO widgets */
-    use_ratio = using_ratio();
-
-    /* If proftpd has mod_quotatab and mod_quotatab_file
-       modules we create, show and use the TLS widgets */
-    use_quota = using_quota();
+    use_ratio = using_module("mod_ratio.c");
 
+    /* If proftpd has mod_quotatab.c and mod_quotatab_file.c
+       modules we create, show and use the Quota widgets */
+    if( using_module("mod_quotatab.c")
+    &&  using_module("mod_quotatab_file.c") )
+      use_quota = 1;
 
     /* Create the server tab */
     create_server_tab(widgets);
@@ -179,75 +180,75 @@ int main(int argc, char *argv[])
     /* Create the application configuration directory. */
     make_dir_chmod(GP_APPCONFDIR, "0700");
 
-   /* Add default certificate settings if they are missing */
-   openssl_conf = g_strdup_printf("%s/certs/gadmin-proftpd-openssl.conf", GP_APPCONFDIR);
-   if( ! file_exists(openssl_conf) && use_tls )
-   {
-       info = g_strdup_printf("%s/certs", GP_APPCONFDIR);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), info);
-       g_free(info);
+    /* Add default certificate settings if they are missing */
+    openssl_conf = g_strdup_printf("%s/certs/gadmin-proftpd-openssl.conf", GP_APPCONFDIR);
+    if( ! file_exists(openssl_conf) && use_tls )
+    {
+        info = g_strdup_printf("%s/certs", GP_APPCONFDIR);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), info);
+        g_free(info);
 
-       info = g_strdup_printf("localhost");
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[16]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf("localhost");
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[16]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+          g_free(utf8);
 
-       info = g_strdup_printf("email@example.org");
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[17]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf("email@example.org");
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[17]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+          g_free(utf8);
 
-       info = g_strdup_printf(_("Country"));
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[18]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf(_("Country"));
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[18]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+          g_free(utf8);
 
-       info = g_strdup_printf(_("City"));
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[19]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf(_("City"));
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[19]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+          g_free(utf8);
 
        info = g_strdup_printf(_("Organization name"));
        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[20]), utf8);
        g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        if( utf8!=NULL )
+          g_free(utf8);
 
-       info = g_strdup_printf(_("Organization department"));
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[21]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf(_("Organization department"));
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[21]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+          g_free(utf8);
 
-       info = g_strdup_printf("EN");
-       utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
-       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[24]), utf8);
-       g_free(info);
-       if( utf8!=NULL )
-         g_free(utf8);
+        info = g_strdup_printf("EN");
+        utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[24]), utf8);
+        g_free(info);
+        if( utf8!=NULL )
+    	  g_free(utf8);
 
-       gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[11]), 1024);
-       gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[12]), 999999);
-   }
-   g_free(openssl_conf);
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[11]), 1024);
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[12]), 999999);
+    }
+    g_free(openssl_conf);
 
 
-   conf_path = g_strdup_printf("%s", PROFTPD_CONF);
+    conf_path = g_strdup_printf("%s", PROFTPD_CONF);
 
-   /* Add default settings file if its missing */
-   settings_conf = g_strdup_printf("%s/settings.conf", GP_APPCONFDIR);
-   if( ! file_exists(settings_conf) )
-   {
+    /* Add the default gadmin-proftpd settings file if its missing */
+    settings_conf = g_strdup_printf("%s/settings.conf", GP_APPCONFDIR);
+    if( ! file_exists(settings_conf) )
+    {
 	if((fp = fopen(settings_conf, "w+")) == NULL)
 	{
 	    info = g_strdup_printf(_("Error: Unable to create new settings file here:\n%s\n"), settings_conf);
@@ -274,14 +275,13 @@ int main(int argc, char *argv[])
 	fclose(fp);
 	g_free(settings);
 	
-	/* If proftpd.conf exists, add the new TLS settings */
+	/* If proftpd.conf exists, switch to the new TLS settings */
 	if( file_exists(conf_path) )
 	{
-	    /* Switches to the new mod_tls.c definition. */
 	    new_tls_module_conf();
 	}
-   }
-   g_free(settings_conf);
+    }
+    g_free(settings_conf);
 
 
     /* Use systems passwd files by default */
@@ -291,11 +291,13 @@ int main(int argc, char *argv[])
     GP_GSHADOW_BUF = g_strdup_printf("%s", GP_GSHADOW);
 
 
-    /* If theres no proftpd.conf, add one */
+    /* If theres no proftpd.conf, add one. */
     if( ! file_exists(conf_path) )
       add_standard_conf(widgets);
     else
-    /* If proftpd.conf is bad, ask to add a new one */
+    /* If proftpd.conf is bad, ask to add a new one.
+       To support dynamically loaded modules we merge
+       any ModulePath and LoadModule statements. */
     if( ! conf_ok(conf_path) )
       create_standard_conf_question(widgets);
     else
@@ -312,8 +314,7 @@ int main(int argc, char *argv[])
     add_standard_users(widgets);
 
 
-    /* If theres no ftpusers one will be made containing 
-       all current usernames (security). */
+    /* If theres no ftpusers one will be made containing all current usernames (security). */
     if((fp=fopen(GP_FTPUSERS, "r"))==NULL)
       auto_security = 1;
     else
@@ -345,7 +346,6 @@ int main(int argc, char *argv[])
 	g_free(cmd);
     }
 
-
     /* Fix for broken Fedora-3,4,5,6,7 proftpd rpm */
     if(  file_exists("/etc/fedora-release") 
     &&   file_exists("/etc/pam.d")
@@ -380,12 +380,10 @@ int main(int argc, char *argv[])
 	g_free(broken_fedora);
     }
 
-
     /* Window close button (x) */   
     g_signal_connect(GTK_OBJECT(widgets->main_window), "destroy",
 	             GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 
-
     gtk_timeout_add(1000, (GtkFunction) status_update, widgets);
 
     gtk_main();
@@ -395,7 +393,6 @@ int main(int argc, char *argv[])
     g_free(GP_SHADOW_BUF);
     g_free(GP_GROUP_BUF);
     g_free(GP_GSHADOW_BUF);
-
 					
     g_free(widgets);
 
