@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ void populate_servers(struct w *widgets)
 	if( commented(line) )
 	  continue;
 
-	if( cmplowercase(line, "<virtualhost ") || cmplowercase(line, "<snonymous "))
+	if( cmplowercase(line, "<virtualhost ") || cmplowercase(line, "<anonymous "))
 	  break;
 	
 	new_buffer[0]='\0';
