@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -140,10 +140,10 @@ void populate_user_settings(struct w *widgets)
     gchar *utf8=NULL;
     gchar *info;
     GtkTreeIter iter;
-    char *new_buffer, *old_buffer, *user_buffer, *address_buffer;
+    char *new_buffer, *line, *user_buffer, *address_buffer;
     char *port_buffer, *spinval;
     char *fr, *frc, *br, *brc; /* Used for ratio settings */
-    long conf_size;
+    long file_size;
     int found = 0, homedir_vals_set = 0, i = 0, x = 0;
     int stats_checked = 1;
     gint spinvalue = 0;
@@ -154,7 +154,6 @@ void populate_user_settings(struct w *widgets)
 
     username = g_strdup_printf("%s", global_user_name);
 
-
     /* Always set an empty password */
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[1]), "");
 
@@ -217,11 +216,11 @@ void populate_user_settings(struct w *widgets)
         return;
     }
     fseek(fp, 0, SEEK_END);
-    conf_size = ftell(fp);
+    file_size = ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(conf_size+1);
-    new_buffer = allocate(conf_size+1);
+    line = allocate(file_size+1);
+    new_buffer = allocate(file_size+1);
     user_buffer = allocate(4096);
     address_buffer = allocate(8192);
     port_buffer = allocate(8192);
@@ -249,19 +248,19 @@ void populate_user_settings(struct w *widgets)
     /* Scroll to the selected vhost */
     if( strstr((char *)global_server_type, "Virtualhost") )
     {
-	if( conf_size > 1 )
-	while(fgets(old_buffer, conf_size, fp)!=NULL)
+	if( file_size > 1 )
+	while(fgets(line, file_size, fp)!=NULL)
 	{
 	    /* If its the correct address */
-	    if( strcmp(old_buffer, address_buffer) == 0 )
+	    if( strcmp(line, address_buffer) == 0 )
 	    {
-	       while(fgets(old_buffer, conf_size, fp)!=NULL)
+	       while(fgets(line, file_size, fp)!=NULL)
 	       {
 		  /* This server was not the right one */
-		  if( strstr(old_buffer, "</VirtualHost>") )
+		  if( strstr(line, "</VirtualHost>") )
 		    break;
 		 
-		  if( strcmp(old_buffer, port_buffer) == 0 )
+		  if( strcmp(line, port_buffer) == 0 )
 		  {
 		     found = 1;
 	             break;
@@ -273,23 +272,22 @@ void populate_user_settings(struct w *widgets)
 	}
     }
 
-
     /* We have scrolled to a vhost or just began at the top */
     found = 0;
 
-    if( conf_size > 1 )
-    while(fgets(old_buffer, conf_size, fp)!=NULL)
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
     {
 	/* Pick up all <Anonymous (with the the root directory) */
-	if( strstr(old_buffer, "<Anonymous") )
-          strcpy(new_buffer, old_buffer);
+	if( strstr(line, "<Anonymous") )
+          strcpy(new_buffer, line);
 
-	if( strlen(old_buffer) > 4000 )
+	if( strlen(line) > 4000 )
 	{
 	    info = g_strdup_printf(_("A line with over 4000 chars is not valid in:\n%s\n"), PROFTPD_CONF);
 	    show_info(info);
 	    fclose(fp);
-	    free(old_buffer);
+	    free(line);
 	    free(new_buffer);
 	    free(user_buffer);
 	    free(address_buffer);
@@ -298,10 +296,9 @@ void populate_user_settings(struct w *widgets)
 	    return;
 	}
 
-
-	/* We have found the correct user .. insert the settings */
-	if( strcmp(old_buffer, user_buffer) == 0 && ! strstr(old_buffer, "AllowUser")
-        &&  ! strstr(old_buffer, "DenyUser") && ! strstr(old_buffer, "FakeUser") )
+	/* We have found the correct user, insert its settings */
+	if( strcmp(line, user_buffer) == 0 && ! strstr(line, "AllowUser")
+        &&  ! strstr(line, "DenyUser") && ! strstr(line, "FakeUser") )
 	{
 		/* Insert the root directory to the directory treeview (collected in the loop above) */
 		new_buffer[strlen(new_buffer)-2]='\0';
@@ -310,25 +307,25 @@ void populate_user_settings(struct w *widgets)
 		gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 0, utf8, -1);
 
 		/* Username on the line after <Anonymous /var/ftp/dir> (cant be set before root dir) */
-		sscanf(old_buffer, "%*s %s", new_buffer);
+		sscanf(line, "%*s %s", new_buffer);
 		utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
 		gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[0]), utf8);
 
 		found = 1;
 
 		/* Insert all the standard values like user, group etc */
-		while(fgets(old_buffer, conf_size, fp)!=NULL)
+		while(fgets(line, file_size, fp)!=NULL)
 		{
-    		    if( strstr(old_buffer, "Group") && found ) 
+    		    if( strstr(line, "Group") && found ) 
     		    {
-			sscanf(old_buffer, "%*s %s", new_buffer);
+			sscanf(line, "%*s %s", new_buffer);
 			utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
 			gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[2]), utf8);
     		    }
 
-    		    if( strstr(old_buffer, "AnonRequirePassword") && found ) 
+    		    if( strstr(line, "AnonRequirePassword") && found ) 
     		    {
-			sscanf(old_buffer, "%*s %s", new_buffer);
+			sscanf(line, "%*s %s", new_buffer);
 			
 			if( strstr(new_buffer, "off") ) /* cant use 'on' so this is reversed */
     			  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[1]), FALSE);
@@ -336,9 +333,9 @@ void populate_user_settings(struct w *widgets)
     			  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[1]), TRUE);
     		    }
 
-    		    if( strstr(old_buffer, "Allow from") && found )
+    		    if( strstr(line, "Allow from") && found )
     		    {
-        		strcpy(new_buffer, old_buffer);
+        		strcpy(new_buffer, line);
 			for(i=0; new_buffer[i]!='\0'; i++)
 			{
 			    if( i >= 2 && new_buffer[i-2]=='m' )
@@ -353,16 +350,16 @@ void populate_user_settings(struct w *widgets)
 			}	    
     		    }
 
-    		    if( strstr(old_buffer, "MaxClients") && found )
+    		    if( strstr(line, "MaxClients") && found )
     		    {
-			for(x=0; old_buffer[x]!='\0'; x++)
+			for(x=0; line[x]!='\0'; x++)
 			{
-	    	    	   if( old_buffer[x]=='"' )
+	    	    	   if( line[x]=='"' )
 		    	     break;
 			}
 			x++;
-			if( old_buffer[x]!='\0' )
-	    	          sprintf(new_buffer, "%s", &old_buffer[x]);
+			if( line[x]!='\0' )
+	    	          sprintf(new_buffer, "%s", &line[x]);
 			for(x=0; new_buffer[x]!='\0'; x++)
 			{
 	    	    	    if( new_buffer[x]=='"' )
@@ -373,7 +370,7 @@ void populate_user_settings(struct w *widgets)
 			}
 			/* Max clients spinbutton */
 			spinval = allocate(4096);
-			sscanf(old_buffer, "%*s %s", spinval);
+			sscanf(line, "%*s %s", spinval);
 			if( chars_are_digits(spinval) )
 			{
 			    spinvalue = atoi(spinval);
@@ -384,7 +381,7 @@ void populate_user_settings(struct w *widgets)
 
 
 		    /* Ratio Module */
-    		    if( use_ratio && strstr(old_buffer, "UserRatio ") && found )
+    		    if( use_ratio && strstr(line, "UserRatio ") && found )
     		    {
 			/* Allocating all at once for clarity */
 			fr  = allocate(4096);
@@ -393,7 +390,7 @@ void populate_user_settings(struct w *widgets)
 			brc = allocate(4096);
 
 			/* Get the ratio numbers (file ratio, fileratio credit, byte ratio, byte ratio credit) */
-			sscanf(old_buffer, "%*s %*s %s %s %s %s", fr, frc, br, brc);
+			sscanf(line, "%*s %*s %s %s %s %s", fr, frc, br, brc);
 			
 			/* Byte ratio spinbutton */
 			if( chars_are_digits(br) )
@@ -430,19 +427,19 @@ void populate_user_settings(struct w *widgets)
 
 
 		    /* AllowOverwite setting in the directory treeview for the root directory */
-		    if( strstr(old_buffer, "AllowOverwrite on") )
+		    if( strstr(line, "AllowOverwrite on") )
 		      gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 6, 1, -1);
 
 
 		    /* Append the Home directory values */
-		    if( strstr(old_buffer, "<Limit") 
-		    && ! strstr(old_buffer, "<Limit LOGIN") 
+		    if( strstr(line, "<Limit") 
+		    && ! strstr(line, "<Limit LOGIN") 
 		    && homedir_vals_set == 0 )
 		    {
-        		strcpy(new_buffer, old_buffer);
-			while(fgets(old_buffer, conf_size, fp)!=NULL)
+        		strcpy(new_buffer, line);
+			while(fgets(line, file_size, fp)!=NULL)
 			{
-			    if( strstr(old_buffer, "Allow") )
+			    if( strstr(line, "Allow") )
 			    {
 				homedir_vals_set = 1;
 				set_toggle_values(new_buffer, iter, widgets);
@@ -454,9 +451,9 @@ void populate_user_settings(struct w *widgets)
 
 
 		    /* Append other directories to the directory treeview */
-		    if( strstr(old_buffer, "<Directory ") && found )
+		    if( strstr(line, "<Directory ") && found )
 		    {
-        		strcpy(new_buffer, old_buffer);
+        		strcpy(new_buffer, line);
 			for(i=0; new_buffer[i]!='\0'; i++)
 			{
 	    		    /* "y " */
@@ -476,34 +473,32 @@ void populate_user_settings(struct w *widgets)
 			}	    
 
 			/* List settings for this directory */
-			while(fgets(old_buffer, conf_size, fp)!=NULL)
+			while(fgets(line, file_size, fp)!=NULL)
 			{
-			    if( strstr(old_buffer, "</Directory") 
-			    ||  strstr(old_buffer, "</Anonymous")
-			    ||  strstr(old_buffer, "</Limit") )
+			    if( strstr(line, "</Directory") 
+			    ||  strstr(line, "</Anonymous")
+			    ||  strstr(line, "</Limit") )
 		    	      break;
 
 
 			    /* AllowOverwite on/off directory treeview checkbutton */
-			    if( strstr(old_buffer, "AllowOverwrite on") )
+			    if( strstr(line, "AllowOverwrite on") )
 		    	      gtk_list_store_set(GTK_LIST_STORE(widgets->directory_store), &iter, 6, 1, -1);
 			    
 			    /* Save the allow limit line with the cmds */
-			    if( strstr(old_buffer, "<Limit") )
+			    if( strstr(line, "<Limit") )
 			    {
-			        snprintf(new_buffer, 1000, "%s", old_buffer);
+			        snprintf(new_buffer, 1000, "%s", line);
 
-				while(fgets(old_buffer, conf_size, fp)!=NULL)
+				while(fgets(line, file_size, fp)!=NULL)
 				{
 
-				    if( strstr(old_buffer, "</Directory") 
-				    ||  strstr(old_buffer, "</Anonymous")
-				    ||  strstr(old_buffer, "</Limit") )
+				    if( strstr(line, "</Directory") 
+				    ||  strstr(line, "</Anonymous")
+				    ||  strstr(line, "</Limit") )
 			    	      break;
 				      
-
-
-				    if( strstr(old_buffer, "Allow") && ! strstr(old_buffer, "AllowOverwrite") )
+				    if( strstr(line, "Allow") && ! strstr(line, "AllowOverwrite") )
 				    {
 					/* We have a limit allow directive (with cmds, FIXME) */
 					set_toggle_values(new_buffer, iter, widgets);
@@ -516,12 +511,12 @@ void populate_user_settings(struct w *widgets)
 		    }   /* If the line contained "<Directory" and the user is found end. */
 		    
 
-		    if( strstr(old_buffer, "#gplockstats") && found )
+		    if( strstr(line, "#gplockstats") && found )
 		      stats_checked = 0;
 		    
 		
 		    /* The user has been listed .. break */
-		    if( strstr(old_buffer, "</Anonymous") )
+		    if( strstr(line, "</Anonymous") )
 		      break;
 		}
 	}
@@ -530,11 +525,9 @@ void populate_user_settings(struct w *widgets)
 	  break;
     }
     fclose(fp);
-    free(old_buffer);
+    free(line);
     free(new_buffer);
     free(user_buffer);
-//    gtk_tree_path_free(path);
-
 
     /* Statistics checkbutton */
     if( stats_checked )
@@ -557,7 +550,7 @@ void populate_user_settings(struct w *widgets)
 
     /* Select the shell we just got in the shell combo box */
     GtkListStore *shell_store;
-    shell_store = GTK_LIST_STORE (gtk_combo_box_get_model(GTK_COMBO_BOX(widgets->user_set_combo[0])));
+    shell_store = GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(widgets->user_set_combo[0])));
 
     if( shell_store )
     {
@@ -586,6 +579,5 @@ void populate_user_settings(struct w *widgets)
     if( utf8!=NULL )
       g_free(utf8);
 
-
     gtk_widget_show_all(widgets->main_window);
 }
