@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,11 +48,12 @@ void populate_users(struct w *widgets)
     FILE *fp;
     GtkTreeIter iter;
     GtkTreePath *path;
+    GtkTreeModel *list_store;
     char *old_buffer, *new_buffer, *address_buffer, *port_buffer, *translate;
     long conf_size;
     gboolean edit=0;
     int found_user=0, found_server=0;
-    gchar *user_comment;
+    gchar *user, *user_comment;
     gchar *utf8=NULL;
 
     gtk_list_store_clear(widgets->user_store);
@@ -150,6 +151,10 @@ void populate_users(struct w *widgets)
     		    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
     		    gtk_list_store_set(GTK_LIST_STORE(widgets->user_store), &iter, 0, utf8, -1);
 
+// new
+		    /* Set the global username */
+//		    snprintf(global_user_name, 1000, "%s", new_buffer);
+
 		    /* Insert user comment */
 		    user_comment = get_user_setting(new_buffer, "comment");
     		    utf8 = g_locale_to_utf8(user_comment, strlen(user_comment), NULL, NULL, NULL);
@@ -223,7 +228,6 @@ void populate_users(struct w *widgets)
     free(address_buffer);
     free(port_buffer);
 
-
     if( utf8 !=NULL )
       g_free(utf8);
 
@@ -237,5 +241,14 @@ void populate_users(struct w *widgets)
     
     path = gtk_tree_path_new_first();
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(widgets->user_treeview), path, NULL, edit);
+
+    /* Set this user as globally selected */
+    list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->user_treeview));
+    gtk_tree_model_get_iter(list_store, &iter, path);
+    gtk_tree_model_get(list_store, &iter, 0, &user, -1);
+
+    sprintf(global_user_name, "%s", (gchar *)user?user:"None");
+    g_free(user);
+
     gtk_tree_path_free(path);
 }
