@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@ void set_version(struct w *widgets)
     gchar *ver=NULL;
     gchar *utf8=NULL;
     gchar *info;
+    GdkColor color;
 
     command = g_strdup_printf("%s -v 2>&1", PROFTPD_BINARY);
     if((fp=popen(command, "r"))==NULL)
@@ -83,6 +84,10 @@ void set_version(struct w *widgets)
         gtk_label_set_text(GTK_LABEL(widgets->version_label), utf8);
 	g_free(utf8);
 	g_free(ver);
+
+	/* Set status color */
+	gdk_color_parse("red", &color);
+	gtk_widget_modify_fg(widgets->version_label, GTK_STATE_NORMAL, &color);
     }
 
     /* Used to determine what options to use with various versions of proftpd */
