@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -139,8 +139,9 @@ int conf_ok(gchar *file_path)
     int good_conf = 0;
 
     if((fp=fopen(file_path, "r"))==NULL)
-      return retval;
-
+    {
+        return retval;
+    }
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
@@ -237,14 +238,15 @@ void backup_configuration(struct w *widgets)
 }
 
 
-/* Backup button in the configuration tab backs up the conf with added "...-admin-backup" */
+/* Backup button in the configuration tab backs up the conf with an added "-gadmin-backup" tag to it */
+/* Manual backups are not automatically overwritten then. */
 void force_configuration_backup(struct w *widgets)
 {
     gchar *cmd, *info;
 
     if( file_exists(PROFTPD_CONF) )
     {
-	cmd = g_strdup_printf("cp %s %s-admin-backup", PROFTPD_CONF, PROFTPD_CONF_BACKUP);
+	cmd = g_strdup_printf("cp %s %s-gadmin-backup", PROFTPD_CONF, PROFTPD_CONF_BACKUP);
 	if( ! run_command(cmd) )
 	{
 	    info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"), PROFTPD_CONF);
@@ -252,7 +254,7 @@ void force_configuration_backup(struct w *widgets)
 	    g_free(info);
 	}
 	else
-	{   /* Dont make "-admin-backup" translatable. */
+	{
 	    info = g_strdup_printf(_("The configuration was backed up here for safety:\n%s%s\n"), PROFTPD_CONF_BACKUP, "-admin-backup");
 	    show_info(info);
 	    g_free(info);
@@ -268,9 +270,13 @@ void restore_configuration(struct w *widgets)
     gchar *info=NULL, *cmd=NULL, *path=NULL;
 
     path = get_dialog_path_selection("FILE", GP_APPCONFDIR, "None");
+
     /* conf_ok() also checks that the configuration lines have valid length */
+
+printf("EEK: %s\n", path);
+
     if( path!=NULL && strlen(path) > 8
-    &&  conf_ok(path) && strstr(path, "proftpd.conf") )
+    &&  conf_ok(path) ) //&& strstr(path, "proftpd.conf") )
     {
 	cmd = g_strdup_printf("cp %s %s", path, PROFTPD_CONF);
 	if( ! run_command(cmd) )
@@ -279,6 +285,7 @@ void restore_configuration(struct w *widgets)
 	    show_info(info);
 	    g_free(info);
 	}
+	g_free(cmd);
 	g_free(path);
 	path = NULL;
     }
@@ -296,22 +303,38 @@ void restore_configuration(struct w *widgets)
 }
 
 
+/* Adds a default/standard configuration and also adds any ModulePath and
+   LoadModule statements from the old conf if any, for included DSO's. */
 void add_standard_conf(struct w *widgets)
 {
-    /* Adds the default configuration */
     FILE *fp;
+    char *includes = NULL;
     gchar *info, *config;
 
-    /* First backup the old configuration */
+    /* First backup/copy the old configuration */
     backup_configuration(widgets);
 
+    /* Get ModulePath and LoadModule statements from included configurations. */
+    includes = get_dynamic_module_statements();
+
     if((fp=fopen(PROFTPD_CONF, "w+"))==NULL)
     {
 	info = g_strdup_printf(_("Cant write a new proftpd.conf here:\n%s\n"), PROFTPD_CONF);
 	show_info(info);
 	g_free(info);
+	if( includes!=NULL )
+	  free(includes);
 	return;
     }
+
+    /* Add any Include lines we found at the top of the conf. */
+    if( includes!=NULL )
+    {
+	fputs(includes, fp);
+	free(includes);
+	fputs("\n", fp);
+    }
+
     /* Note: inetd functions would limit the servers usability */
     config = g_strconcat(
     "ServerType standalone\n",
@@ -347,7 +370,13 @@ void add_standard_conf(struct w *widgets)
     "TransferRate STOU 250\n",
     "TransferRate APPE 250\n",
     "SystemLog ", GP_VARDIR, "/log/secure\n",
-    "RequireValidShell off\n",
+    "RequireValidShell off\n\n",
+
+#ifdef CAN_BE_ANNOYING_FOR_USERS
+    "<IfModule mod_delay.c>\n"
+    "DelayEngine on\n"
+    "</IfModule>\n\n"
+#endif
 
     "<IfModule mod_tls.c>\n",
     "TLSEngine off\n",
